@@ -7,28 +7,25 @@ urls.py
 """
 
 from django.conf.urls.defaults import patterns
-from django.views.generic.simple import redirect_to
 
 from feedjack import views
 
 
 
 urlpatterns = patterns('',
-    (r'^rss20.xml$', redirect_to,
-      {'url':'/feed/rss/'}),
-    (r'^feed/$', redirect_to,
-      {'url':'/feed/atom/'}),
+    (r'^rss20.xml$', views.rssfeed),
+    (r'^feed/$', views.atomfeed),
+
     (r'^feed/rss/$', views.rssfeed),
     (r'^feed/atom/$', views.atomfeed),
 
-    (r'^feed/user/(?P<user>\d+)/tag/(?P<tag>.*)/$', redirect_to,
-      {'url':'/feed/atom/user/%(user)s/tag/%(tag)s/'}),
-    (r'^feed/user/(?P<user>\d+)/$', redirect_to,
-      {'url':'/feed/atom/user/%(user)s/'}),
-    (r'^feed/tag/(?P<tag>.*)/$', redirect_to,
-      {'url':'/feed/atom/tag/%(tag)s/'}),
+    (r'^feed/user/(?P<user>\d+)/tag/(?P<tag>.*)/$',  views.atomfeed),
 
-    (r'^feed/atom/user/(?P<user>\d+)/tag/(?P<tag>.*)/$', views.atomfeed),
+    (r'^feed/user/(?P<user>\d+)/$', views.atomfeed),
+
+    (r'^feed/tag/(?P<tag>.*)/$',  views.atomfeed),
+
+    (r'^feed/atom/user/(?P<user>\d+)/tag/(?P<tag>.*)/$',views.atomfeed),
     (r'^feed/atom/user/(?P<user>\d+)/$', views.atomfeed),
     (r'^feed/atom/tag/(?P<tag>.*)/$', views.atomfeed),
     (r'^feed/rss/user/(?P<user>\d+)/tag/(?P<tag>.*)/$', views.rssfeed),
@@ -44,4 +41,4 @@ urlpatterns = patterns('',
     (r'^$', views.mainview),
 )
 
-#~
+
